"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ListenerLayer = void 0;
const events_1 = require("events");
const enum_1 = require("../../model/enum/");
const whatsapp_1 = require("./whatsapp");
class ListenerLayer extends whatsapp_1.Whatsapp {
    constructor(page, browser, options, ev) {
        super(page, browser, options, ev);
        this.page = page;
        this.browser = browser;
        this.options = options;
        this.ev = ev;
        this.listenerEmitter = new events_1.EventEmitter();
    }
    async initListener() {
        const functions = Object.values(enum_1.OnModeListener);
        for (const func of functions) {
            const hasFunction = await this.page
                .evaluate((funcName) => typeof window[funcName] === 'function', func)
                .catch(() => false);
            if (!hasFunction) {
                // Expose the function to the page
                await this.page
                    .exposeFunction(func, (...args) => {
                    this.listenerEmitter.emit(func, ...args);
                })
                    .catch(() => undefined);
                this.listener(enum_1.OnModeListener[func]);
                // Start the function if it's defined in this class
                if (typeof this[func] === 'function') {
                    this[func]();
                }
            }
        }
    }
    listener(type) {
        this.listenerEmitter.on(type, (event) => {
            this.ev.emitStatusFind({
                onType: type,
                session: this.options.session,
                result: event,
            });
        });
        return {
            dispose: () => {
                this.listenerEmitter.off(type, (event) => {
                    this.ev.emitStatusFind({
                        onType: type,
                        session: this.options.session,
                        result: event,
                    });
                });
            },
        };
    }
}
exports.ListenerLayer = ListenerLayer;
