import { Page, Browser } from 'puppeteer';
import { CreateOptions } from '../../model/interface/';
import { OnMod } from './on-wpp';
export declare class Scraping extends OnMod {
    page: Page;
    browser: Browser;
    options: CreateOptions;
    ev: any;
    startScanQrcode: boolean;
    autoCloseInterval: any;
    autoCloseRemain: number;
    scanPhoneNumbersActive: boolean;
    scanQrCodeActive: boolean;
    protected urlCode: any;
    constructor(page: Page, browser: Browser, options: CreateOptions, ev: any);
    /**
     * Function to get the pairing type
     * @returns string
     */
    getPairingType(): Promise<string>;
    /**
     * Function to determine which click interface to use for retrieving a phone number
     * @returns boolean
     */
    withPhoneNumber(): Promise<boolean>;
    /**
     * Function to check if the phone number input is visible
     * @returns boolean
     */
    checkInputVisiblePhoneNumber(): Promise<boolean>;
    /**
     * Function to scan phone numbers
     */
    scanPhoneNumbers(): Promise<void>;
    /**
     * Handles the generation of a phone number code
     */
    private handleCodeGeneration;
    /**
     * Handles the refreshing and re-generation of a phone number code
     */
    private handleCodeRefresh;
    /**
     * Emits the status of the code generation or error
     */
    private emitCodeStatus;
    /**
     * Function to qrcode scan
     */
    qrCodeScan(): Promise<void>;
    /**
     * Function try auto close session
     */
    protected tryAutoClose(): void;
    /**
     * Function cancel auto close session
     */
    cancelAutoClose(): void;
    /**
     * Function start auto close session
     */
    protected startAutoClose(): void;
    /**
     * Function scrape qrcode from page whatsapp web and return base64 image and code
     * @returns - base64Image and urlCode
     */
    qrCode(): Promise<{
        base64Image: string;
        urlCode: string | null;
    } | undefined>;
    /**
     * Function generate ascii qr code
     * @param code - code to generate ascii qr code
     * @returns - ascii qr code
     */
    asciiQr(code: string): Promise<string>;
}
