"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Scraping = void 0;
const enum_1 = require("../../model/enum");
const on_wpp_1 = require("./on-wpp");
const help_1 = require("../../help");
const qrcode = __importStar(require("qrcode-terminal"));
const enum_2 = require("../../model/enum");
class Scraping extends on_wpp_1.OnMod {
    constructor(page, browser, options, ev) {
        super(page, browser, options, ev);
        this.page = page;
        this.browser = browser;
        this.options = options;
        this.ev = ev;
        this.autoCloseRemain = 0;
        this.scanPhoneNumbersActive = false;
        this.scanQrCodeActive = false;
        this.urlCode = '';
        this.startScanQrcode = false;
    }
    /**
     * Function to get the pairing type
     * @returns string
     */
    async getPairingType() {
        try {
            return await this.page.evaluate(() => {
                return window.Store.DeviceLinkingApi.getPairingType();
            });
        }
        catch (error) {
            console.error('Error in getPairingType:', error);
            throw error;
        }
    }
    /**
     * Function to determine which click interface to use for retrieving a phone number
     * @returns boolean
     */
    async withPhoneNumber() {
        try {
            return await this.page.evaluate(() => {
                const chevronElement = document.querySelector('span[data-icon="chevron"]');
                const parentElement = chevronElement === null || chevronElement === void 0 ? void 0 : chevronElement.parentElement;
                if (parentElement) {
                    parentElement.click();
                    return true;
                }
                return false;
            });
        }
        catch (error) {
            console.error('Error in withPhoneNumber:', error);
            throw error;
        }
    }
    /**
     * Function to check if the phone number input is visible
     * @returns boolean
     */
    async checkInputVisiblePhoneNumber() {
        try {
            return await this.page.evaluate(() => {
                return Boolean(document.querySelector('.selectable-text'));
            });
        }
        catch (error) {
            console.error('Error in checkInputVisiblePhoneNumber:', error);
            throw error;
        }
    }
    /**
     * Function to scan phone numbers
     */
    async scanPhoneNumbers() {
        var _a, _b, _c;
        this.scanPhoneNumbersActive = true;
        this.startAutoClose();
        let firstCode = false;
        const phoneNumber = ((_a = this.options.loginWithPhoneNumber) === null || _a === void 0 ? void 0 : _a.phoneNumber) || false;
        while (true) {
            try {
                const checkInterface = await this.handleApiCallParametres(enum_2.FunctionsLayer.getInterface);
                if (checkInterface.mode !== enum_1.InterfaceMode.QR || !phoneNumber) {
                    break;
                }
                const getPairingType = await this.getPairingType();
                if (getPairingType === 'QR_CODE') {
                    await this.withPhoneNumber();
                    await (0, help_1.sleep)(2000);
                }
                else if (getPairingType === 'ALT_DEVICE_LINKING') {
                    const selectable = await this.checkInputVisiblePhoneNumber();
                    if (selectable) {
                        if (!firstCode) {
                            await this.handleCodeGeneration(phoneNumber);
                            firstCode = true;
                        }
                        else {
                            await this.handleCodeRefresh(phoneNumber);
                        }
                    }
                    await (0, help_1.sleep)((_c = (_b = this.options.loginWithPhoneNumber) === null || _b === void 0 ? void 0 : _b.timeRefeshCode) !== null && _c !== void 0 ? _c : 120000);
                }
            }
            catch (error) {
                console.error('Error in scanPhoneNumbers loop:', error);
            }
        }
    }
    /**
     * Handles the generation of a phone number code
     */
    async handleCodeGeneration(phoneNumber) {
        try {
            const code = await this.handleApiCallParametres(enum_2.FunctionsLayer.getCodeForPhoneNumber, phoneNumber);
            this.emitCodeStatus(code);
        }
        catch (error) {
            console.error('Error in handleCodeGeneration:', error);
        }
    }
    /**
     * Handles the refreshing and re-generation of a phone number code
     */
    async handleCodeRefresh(phoneNumber) {
        try {
            const refreshCode = await this.handleApiCallParametres(enum_2.FunctionsLayer.refreshAltLinkingCode);
            if (refreshCode) {
                await this.handleCodeGeneration(phoneNumber);
            }
        }
        catch (error) {
            console.error('Error in handleCodeRefresh:', error);
        }
    }
    /**
     * Emits the status of the code generation or error
     */
    emitCodeStatus(code) {
        var _a, _b;
        if (typeof code === 'string') {
            this.ev.emitStatusFind({
                error: false,
                code: code,
                onType: enum_1.OnMode.codePhoneNumber,
                session: this.options.session,
                phoneNumber: (_a = this.options.loginWithPhoneNumber) === null || _a === void 0 ? void 0 : _a.phoneNumber,
            });
        }
        else {
            this.ev.emitStatusFind({
                error: true,
                text: 'Error in get code phone number',
                code: code,
                onType: enum_1.OnMode.codePhoneNumber,
                session: this.options.session,
                phoneNumber: (_b = this.options.loginWithPhoneNumber) === null || _b === void 0 ? void 0 : _b.phoneNumber,
            });
        }
    }
    /**
     * Function to qrcode scan
     */
    async qrCodeScan() {
        var _a;
        this.startAutoClose();
        this.scanQrCodeActive = true;
        await this.page
            .waitForFunction(`document.querySelector('canvas')`)
            .catch(() => undefined);
        while (true) {
            const checkInterface = await this.handleApiCallParametres(enum_2.FunctionsLayer.getInterface);
            if (checkInterface.mode !== enum_1.InterfaceMode.QR) {
                break;
            }
            const result = await this.qrCode().catch();
            if (!(result === null || result === void 0 ? void 0 : result.urlCode)) {
                break;
            }
            if (this.urlCode !== result.urlCode) {
                this.urlCode = result.urlCode;
                this.ev.emitStatusFind({
                    error: false,
                    qrcode: result.urlCode,
                    base64Image: result.base64Image,
                    onType: enum_1.OnMode.qrcode,
                    session: this.options.session,
                });
                const qr = await this.asciiQr(this.urlCode).catch(() => undefined);
                if (this.options.printQRInTerminal) {
                    console.log(qr);
                }
            }
            await ((_a = (0, help_1.sleep)(100)) === null || _a === void 0 ? void 0 : _a.catch(() => undefined));
        }
    }
    /**
     * Function try auto close session
     */
    tryAutoClose() {
        if (this.options.timeAutoClose &&
            this.options.timeAutoClose > 0 &&
            !this.autoCloseInterval &&
            !this.page.isClosed()) {
            this.page.close().catch(() => { });
            this.browser.close().catch(() => { });
        }
    }
    /**
     * Function cancel auto close session
     */
    cancelAutoClose() {
        clearInterval(this.autoCloseInterval);
        this.autoCloseInterval = null;
    }
    /**
     * Function start auto close session
     */
    startAutoClose() {
        let remain = this.options.timeAutoClose
            ? this.options.timeAutoClose
            : false;
        if (this.options.timeAutoClose &&
            this.options.timeAutoClose > 0 &&
            !this.autoCloseInterval) {
            try {
                this.autoCloseInterval = setInterval(() => {
                    if (this.page.isClosed()) {
                        this.cancelAutoClose();
                        return;
                    }
                    if (Number.isInteger(remain)) {
                        remain -= 1000;
                        this.autoCloseRemain = Math.round(remain / 1000);
                        if (remain <= 0) {
                            this.ev.emitStatusFind({
                                error: false,
                                text: 'Auto close called!',
                                status: enum_1.TypeStatusFind.autoClose,
                                statusFind: 'browser',
                                onType: enum_1.OnMode.connection,
                                session: this.options.session,
                            });
                            this.cancelAutoClose();
                            this.tryAutoClose();
                        }
                    }
                }, 1000);
            }
            catch (_a) { }
        }
    }
    /**
     * Function scrape qrcode from page whatsapp web and return base64 image and code
     * @returns - base64Image and urlCode
     */
    async qrCode() {
        let click = await this.page
            .evaluate(() => {
            const buttonReload = document.querySelector('button._akas');
            if (buttonReload) {
                return true;
            }
            return false;
        })
            .catch();
        if (click) {
            const buttonReloadElementHandle = await this.page.$('button._akas');
            if (buttonReloadElementHandle) {
                await buttonReloadElementHandle.click();
            }
        }
        const result = await this.page
            .evaluate(() => {
            const selectorImg = document.querySelector('canvas');
            if (selectorImg) {
                const selectorUrl = selectorImg.closest('[data-ref]');
                const buttonReload = document.querySelector('button._akas');
                if (buttonReload === null &&
                    selectorImg != null &&
                    selectorUrl != null) {
                    let data = {
                        base64Image: selectorImg.toDataURL(),
                        urlCode: selectorUrl.getAttribute('data-ref'),
                    };
                    return data;
                }
                else {
                    return undefined;
                }
            }
        })
            .catch();
        return result;
    }
    /**
     * Function generate ascii qr code
     * @param code - code to generate ascii qr code
     * @returns - ascii qr code
     */
    async asciiQr(code) {
        return new Promise((resolve) => {
            try {
                qrcode.generate(code, { small: true }, (qrcode) => {
                    resolve(qrcode);
                });
            }
            catch (e) { }
        });
    }
}
exports.Scraping = Scraping;
